@@ -30,11 +30,11 @@
 #include "../objects/object_factory.h"
 #include "../objects/bogus_imp.h"
 
+#include <KActionCollection>
 #include <KIconEngine>
-#include <kactioncollection.h>
 
 #include <QIcon>
-#include <qregexp.h>
+#include <QRegExp>
 
 int GUIAction::shortcut() const
 {
@@ -91,12 +91,12 @@ KigGUIAction::KigGUIAction( GUIAction* act,
     setIcon( QIcon( new KIconEngine( icon, doc.iconLoader() ) ) );
   setWhatsThis( act->description() );
   QString tooltip = act->descriptiveName();
-  tooltip.replace( QRegExp( "&&" ), "&" );
+  tooltip.replace( QRegExp( "&&" ), QStringLiteral("&") );
   setToolTip( tooltip );
-  setShortcut( QKeySequence( act->shortcut() ) );
-  connect( this, SIGNAL(triggered()), this, SLOT(slotActivated()) );
+  connect( this, &QAction::triggered, this, &KigGUIAction::slotActivated );
 
-    doc.actionCollection()->addAction(act->actionName(), this);
+  doc.actionCollection()->addAction(act->actionName(), this);
+  doc.actionCollection()->setDefaultShortcut( this, QKeySequence( act->shortcut() ) );
 }
 
 void KigGUIAction::slotActivated()
@@ -225,7 +225,7 @@ void AddFixedPointAction::act( KigPart& doc )
   KigInputDialog::getCoordinate(
     i18n( "Fixed Point" ),
     i18n( "Enter the coordinates for the new point." ) +
-    QString::fromLatin1( "<br>" ) +
+    QLatin1String( "<br>" ) +
     doc.document().coordinateSystem().coordinateFormatNoticeMarkup(),
     doc.widget(), &ok, doc.document(), &c );
   if ( ! ok ) return;
